import argparse
from configparser import ConfigParser

def read_user_cli_args():
  
    parser = argparse.ArgumentParser(prog ='gfg',
                                     description ='GfG article demo package.')
  
    parser.add_argument('integers', metavar ='N', type = int, nargs ='+',
                        help ='an integer for the accumulator')
    parser.add_argument('-greet', action ='store_const', const = True,
                        default = False, dest ='greet',
                        help ="Greet Message from Geeks For Geeks.")
    parser.add_argument('--sum', dest ='accumulate', action ='store_const',
                        const = sum, default = max,
                        help ='sum the integers (default: find the max)')
  
    args = parser.parse_args()
  
    if args.greet:
        print("Welcome to GeeksforGeeks !")
        if args.accumulate == max:
            print("The Computation Done is Maximum")
        else:
            print("The Computation Done is Summation")
        print("And Here's your result:", end =" ")   
  
    print(args.accumulate(args.integers))

def test():
    print("Hello World")


# if __name__ == "__main__":
#     test()


from setuptools import setup, find_packages
  
# with open('requirements.txt') as f:
#     requirements = f.readlines()
  
long_description = 'Sample Package made for a demo \
      of its making for the jc3wrld999 Article.'
  
setup(
        name ='w24thr',
        version ='1.0.0',
        author ='jc3wrld999',
        author_email ='jc3wrld999@gmail.com',
        url ='https://github.com/jc3wrld999/w24thr',
        description ='Demo Package for w24thr Article.',
        long_description = long_description,
        # long_description_content_type ="text/markdown",
        license ='MIT',
        packages = ['test'],
        # entry_points ={
        #     'console_scripts': [
        #         'gfg = w24thr.gfg:main'
        #     ]
        # },
        # classifiers =(
        #     "Programming Language :: Python :: 3",
        #     "License :: OSI Approved :: MIT License",
        #     "Operating System :: OS Independent",
        # ),
        keywords ='test',
        install_requires = [],
        zip_safe = False
)